myimagelib.myImageLib.rawImage
==============================

.. currentmodule:: myimagelib.myImageLib

.. autoclass:: rawImage

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~rawImage.__init__
      ~rawImage.extract_tif
      ~rawImage.read_raw_image_info
   
   

   
   
   